==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/TaxDriver_EU.pm <==
package WebGUI::i18n::Dutch::TaxDriver_EU;
use utf8;
our $I18N = {
  'accept when vies unavailable' => {
    'lastUpdated' => '1250839975',
    'message' => 'Ongecontroleerde BTW nummers toestaan als de BTW nummercheckservice niet beschikbaar is?'
  },
  'accept when vies unavailable help' => {
    'lastUpdated' => '1248781627',
    'message' => 'Als een van de databases van de BTW nummercheckservice tijdelijk onbeschikbaar is of als de connectie niet tot stand gebracht kon worden, kunnen BTW nummers niet gecontroleerd worden. Meestal is dit een tijdelijk probleem. Als deze optie op ja staat, worden BTW nummers die niet gecontroleerd konden worden alsnog gebruikt. Let erop dat de samenstelling van BTW nummers altijd gecontroleerd wordt, of de nummercheckservice beschikbaar is of niet.'
  },
  'add' => {
    'lastUpdated' => '1248168540',
    'message' => 'Toevoegen'
  },
  'add vat group' => {
    'lastUpdated' => '1248168566',
    'message' => 'Voeg BTW groep toe'
  },
  'already has vat number' => {
    'lastUpdated' => '1248168598',
    'message' => 'Er is al een BTW nummer voor dit land geregistreerd.'
  },
  'approve' => {
    'lastUpdated' => '1248168573',
    'message' => 'Goedkeuren'
  },
  'auto vies approval' => {
    'lastUpdated' => '1248169013',
    'message' => 'Automatische BTW nummercheck goedkeuring?'
  },
  'auto vies approval help' => {
    'lastUpdated' => '1250839968',
    'message' => 'Als dit op ja gezet is, worden BTW nummers die door de BTW nummerchecksercive gecontroleerd zijn meteen bruikbaar voor de klanten. Als het op nee gezet is moeten de de nummers expliciet goedgekeurd zijn voordat ze bruikbaar zijn.'
  },
  'default group' => {
    'lastUpdated' => '1248168753',
    'message' => 'Standaard groep'
  },
  'delete group' => {
    'lastUpdated' => '1248168678',
    'message' => 'Verwijderen'
  },
  'deny' => {
    'lastUpdated' => '1248168663',
    'message' => 'Afkeuren'
  },
  'general configuration' => {
    'lastUpdated' => '1248168781',
    'message' => 'Algemene configuratie'
  },
  'group name' => {
    'lastUpdated' => '1248168726',
    'message' => 'Groepsnaam'
  },
  'illegal country code' => {
    'lastUpdated' => '1248168799',
    'message' => 'Ongeldige landcode'
  },
  'make default' => {
    'lastUpdated' => '1248168741',
    'message' => 'Stel in als standaard'
  },
  'rate' => {
    'lastUpdated' => '1248168718',
    'message' => 'Tarief'
  },
  'select country' => {
    'lastUpdated' => '1248168765',
    'message' => 'Selecteer een land'
  },
  'shop country' => {
    'lastUpdated' => '1248168691',
    'message' => 'Land van verblijf'
  },
  'shop country help' => {
    'lastUpdated' => '1248170026',
    'message' => 'Selecteer het land waar de winkel zich bevindt. Als het land niet in de lijst staat, is het land geen onderdeel van de Europese Unie en kan deze belastingapplicatie niet gebruikt worden.'
  },
  'user' => {
    'lastUpdated' => '1248168553',
    'message' => 'Gebruiker'
  },
  'user template' => {
    'lastUpdated' => '1248168706',
    'message' => 'Gebruiker scherm sjabloon'
  },
  'user template help' => {
    'lastUpdated' => '1248168984',
    'message' => 'Het sjabloon voor het scherm waar de gebruikers hun BTW nummers in kunnen voeren.'
  },
  'vat group' => {
    'lastUpdated' => '1248168809',
    'message' => 'BTW groep'
  },
  'vat groups' => {
    'lastUpdated' => '1248168820',
    'message' => 'BTW groepen'
  },
  'vat number' => {
    'lastUpdated' => '1248168828',
    'message' => 'BTW nummer'
  },
  'vat number invalid' => {
    'lastUpdated' => '1248168850',
    'message' => 'Het opgegeven BTW nummer is ongeldig.'
  },
  'vat numbers' => {
    'lastUpdated' => '1248168861',
    'message' => 'BTW nummers'
  },
  'vies error code' => {
    'lastUpdated' => '1248168934',
    'message' => 'BTW nummercheck foutcode'
  },
  'vies unavailable' => {
    'lastUpdated' => '1248168650',
    'message' => 'Nummer validatie momenteel niet beschikbaar. Probeer het later nogmaals.'
  },
  'vies validated' => {
    'lastUpdated' => '1248168955',
    'message' => 'BTW nummercheck gecontroleerd'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/TaxDriver_EU.pm <==
package WebGUI::i18n::Dutch::TaxDriver_EU;
use utf8;
our $I18N = {
  'Add another VAT number' => {
    'lastUpdated' => '1297776537',
    'message' => 'Voeg een BTW nummer toe.'
  },
  'Approved for use' => {
    'lastUpdated' => '1297776549',
    'message' => 'Goedgekeurd voor gebruik'
  },
  'Enter VAT numbers' => {
    'lastUpdated' => '1297776563',
    'message' => 'Voer BTW nummers in'
  },
  'accept when vies unavailable' => {
    'lastUpdated' => '1250839975',
    'message' => 'Ongecontroleerde BTW nummers toestaan als de BTW nummercheckservice niet beschikbaar is?'
  },
  'accept when vies unavailable help' => {
    'lastUpdated' => '1248781627',
    'message' => 'Als een van de databases van de BTW nummercheckservice tijdelijk onbeschikbaar is of als de connectie niet tot stand gebracht kon worden, kunnen BTW nummers niet gecontroleerd worden. Meestal is dit een tijdelijk probleem. Als deze optie op ja staat, worden BTW nummers die niet gecontroleerd konden worden alsnog gebruikt. Let erop dat de samenstelling van BTW nummers altijd gecontroleerd wordt, of de nummercheckservice beschikbaar is of niet.'
  },
  'add' => {
    'lastUpdated' => '1248168540',
    'message' => 'Toevoegen'
  },
  'add vat group' => {
    'lastUpdated' => '1248168566',
    'message' => 'Voeg BTW groep toe'
  },
  'already has vat number' => {
    'lastUpdated' => '1248168598',
    'message' => 'Er is al een BTW nummer voor dit land geregistreerd.'
  },
  'approve' => {
    'lastUpdated' => '1248168573',
    'message' => 'Goedkeuren'
  },
  'auto vies approval' => {
    'lastUpdated' => '1248169013',
    'message' => 'Automatische BTW nummercheck goedkeuring?'
  },
  'auto vies approval help' => {
    'lastUpdated' => '1250839968',
    'message' => 'Als dit op ja gezet is, worden BTW nummers die door de BTW nummerchecksercive gecontroleerd zijn meteen bruikbaar voor de klanten. Als het op nee gezet is moeten de de nummers expliciet goedgekeurd zijn voordat ze bruikbaar zijn.'
  },
  'default group' => {
    'lastUpdated' => '1248168753',
    'message' => 'Standaard groep'
  },
  'delete group' => {
    'lastUpdated' => '1248168678',
    'message' => 'Verwijderen'
  },
  'deny' => {
    'lastUpdated' => '1248168663',
    'message' => 'Afkeuren'
  },
  'general configuration' => {
    'lastUpdated' => '1248168781',
    'message' => 'Algemene configuratie'
  },
  'group name' => {
    'lastUpdated' => '1248168726',
    'message' => 'Groepsnaam'
  },
  'illegal country code' => {
    'lastUpdated' => '1248168799',
    'message' => 'Ongeldige landcode'
  },
  'make default' => {
    'lastUpdated' => '1248168741',
    'message' => 'Stel in als standaard'
  },
  'rate' => {
    'lastUpdated' => '1248168718',
    'message' => 'Tarief'
  },
  'select country' => {
    'lastUpdated' => '1248168765',
    'message' => 'Selecteer een land'
  },
  'shop country' => {
    'lastUpdated' => '1248168691',
    'message' => 'Land van verblijf'
  },
  'shop country help' => {
    'lastUpdated' => '1248170026',
    'message' => 'Selecteer het land waar de winkel zich bevindt. Als het land niet in de lijst staat, is het land geen onderdeel van de Europese Unie en kan deze belastingapplicatie niet gebruikt worden.'
  },
  'user' => {
    'lastUpdated' => '1248168553',
    'message' => 'Gebruiker'
  },
  'user template' => {
    'lastUpdated' => '1248168706',
    'message' => 'Gebruiker scherm sjabloon'
  },
  'user template help' => {
    'lastUpdated' => '1248168984',
    'message' => 'Het sjabloon voor het scherm waar de gebruikers hun BTW nummers in kunnen voeren.'
  },
  'vat group' => {
    'lastUpdated' => '1248168809',
    'message' => 'BTW groep'
  },
  'vat groups' => {
    'lastUpdated' => '1248168820',
    'message' => 'BTW groepen'
  },
  'vat number' => {
    'lastUpdated' => '1248168828',
    'message' => 'BTW nummer'
  },
  'vat number invalid' => {
    'lastUpdated' => '1248168850',
    'message' => 'Het opgegeven BTW nummer is ongeldig.'
  },
  'vat numbers' => {
    'lastUpdated' => '1248168861',
    'message' => 'BTW nummers'
  },
  'vies error code' => {
    'lastUpdated' => '1248168934',
    'message' => 'BTW nummercheck foutcode'
  },
  'vies unavailable' => {
    'lastUpdated' => '1248168650',
    'message' => 'Nummer validatie momenteel niet beschikbaar. Probeer het later nogmaals.'
  },
  'vies validated' => {
    'lastUpdated' => '1248168955',
    'message' => 'BTW nummercheck gecontroleerd'
  }
}
;

1;
